@@ -1,6 +1,6 @@
 package Spreadsheet::Reader::ExcelXML;
 our $AUTHORITY = 'cpan:JANDREW';
-use version 0.77; our $VERSION = version->declare('v0.16.2');
+use version 0.77; our $VERSION = version->declare('v0.16.8');
 ###LogSD	warn "You uncovered internal logging statements for Spreadsheet::Reader::ExcelXML-$VERSION";
 
 use 5.010;
@@ -21,7 +21,7 @@ set_args_cloning ( 0 );
 use lib	'../../../../lib',;
 use Spreadsheet::Reader::ExcelXML::Error;
 use Spreadsheet::Reader::ExcelXML::Workbook;
-use Spreadsheet::Reader::Format v0.6.2;
+use Spreadsheet::Reader::Format v0.6.4;
 use Spreadsheet::Reader::Format::FmtDefault;
 use Spreadsheet::Reader::Format::ParseExcelFormatStrings;
 use Spreadsheet::Reader::ExcelXML::Types qw( XLSXFile IOFileType );
@@ -1460,11 +1460,13 @@ B<Default attribute differences>
 
 =over
 
-L<error_inst|/error_inst> =>{
-								superclasses => ['Spreadsheet::Reader::ExcelXML::Error'],
-								package => 'ErrorInstance',
-								should_warn => 1,
-							}
+L<error_inst|/error_inst> ->
+
+	error_inst =>{
+		superclasses => ['Spreadsheet::Reader::ExcelXML::Error'],
+		package => 'ErrorInstance',
+		should_warn => 1,
+	}
 
 L<show_sub_file_size|/show_sub_file_size> => 1
 
@@ -1482,11 +1484,13 @@ B<Default attribute differences>
 
 =over
 
-L<cache_positions|/cache_positions> =>{
-					shared_strings_interface => 209715200,# 200 MB
-					styles_interface => 209715200,# 200 MB
-					worksheet_interface => 209715200,# 200 MB
-				},
+L<cache_positions|/cache_positions> ->
+
+	cache_positions =>{
+		shared_strings_interface => 209715200,# 200 MB
+		styles_interface => 209715200,# 200 MB
+		worksheet_interface => 209715200,# 200 MB
+	},
 
 =back
 
@@ -1502,11 +1506,13 @@ B<Default attribute differences>
 
 =over
 
-L<cache_positions|/cache_positions> =>{
-					shared_strings_interface => 10240,# 10 KB
-					styles_interface => 10240,# 10 KB
-					worksheet_interface => 1024,# 1 KB
-				},
+L<cache_positions|/cache_positions> ->
+
+	cache_positions =>{
+		shared_strings_interface => 10240,# 10 KB
+		styles_interface => 10240,# 10 KB
+		worksheet_interface => 1024,# 1 KB
+	},
 
 =back
 
@@ -1953,7 +1959,7 @@ it and/or modify it under the same terms as Perl itself.
 The full text of the license can be found in the
 LICENSE file included with this module.
 
-This software is copyrighted (c) 2016 by Jed Lund
+This software is copyrighted (c) 2016, 2017 by Jed Lund
 
 =head1 DEPENDENCIES
 
